summaryrefslogtreecommitdiffstats
path: root/src/main/java/org/bukkit/World.java
diff options
context:
space:
mode:
authormd_5 <git@md-5.net>2018-07-15 10:00:00 +1000
committermd_5 <git@md-5.net>2018-07-15 10:00:00 +1000
commitf8b2086d60942eb2cd7ac25a2a1408cb790c222c (patch)
treea3c2dab586f0cd6c23412324aefd83cdab113514 /src/main/java/org/bukkit/World.java
parentbdd0eda71f87cb8ca3b1842bd9bbd43bba5a08bd (diff)
downloadbukkit-f8b2086d60942eb2cd7ac25a2a1408cb790c222c.tar
bukkit-f8b2086d60942eb2cd7ac25a2a1408cb790c222c.tar.gz
bukkit-f8b2086d60942eb2cd7ac25a2a1408cb790c222c.tar.lz
bukkit-f8b2086d60942eb2cd7ac25a2a1408cb790c222c.tar.xz
bukkit-f8b2086d60942eb2cd7ac25a2a1408cb790c222c.zip
Update to Minecraft 1.13-pre7
Diffstat (limited to 'src/main/java/org/bukkit/World.java')
-rw-r--r--src/main/java/org/bukkit/World.java67
1 files changed, 18 insertions, 49 deletions
diff --git a/src/main/java/org/bukkit/World.java b/src/main/java/org/bukkit/World.java
index c8344c6d..f18dff83 100644
--- a/src/main/java/org/bukkit/World.java
+++ b/src/main/java/org/bukkit/World.java
@@ -10,6 +10,7 @@ import java.util.UUID;
import org.bukkit.block.Biome;
import org.bukkit.block.Block;
+import org.bukkit.block.data.BlockData;
import org.bukkit.entity.*;
import org.bukkit.generator.BlockPopulator;
import org.bukkit.inventory.ItemStack;
@@ -31,8 +32,6 @@ public interface World extends PluginMessageRecipient, Metadatable {
* @param y Y-coordinate of the block
* @param z Z-coordinate of the block
* @return Block at the given coordinates
- * @see #getBlockTypeIdAt(int, int, int) Returns the current type ID of
- * the block
*/
public Block getBlockAt(int x, int y, int z);
@@ -41,38 +40,10 @@ public interface World extends PluginMessageRecipient, Metadatable {
*
* @param location Location of the block
* @return Block at the given location
- * @see #getBlockTypeIdAt(org.bukkit.Location) Returns the current type ID
- * of the block
*/
public Block getBlockAt(Location location);
/**
- * Gets the block type ID at the given coordinates
- *
- * @param x X-coordinate of the block
- * @param y Y-coordinate of the block
- * @param z Z-coordinate of the block
- * @return Type ID of the block at the given coordinates
- * @see #getBlockAt(int, int, int) Returns a live Block object at the
- * given location
- * @deprecated Magic value
- */
- @Deprecated
- public int getBlockTypeIdAt(int x, int y, int z);
-
- /**
- * Gets the block type ID at the given {@link Location}
- *
- * @param location Location of the block
- * @return Type ID of the block at the given location
- * @see #getBlockAt(org.bukkit.Location) Returns a live Block object at
- * the given location
- * @deprecated Magic value
- */
- @Deprecated
- public int getBlockTypeIdAt(Location location);
-
- /**
* Gets the y coordinate of the lowest block at this position such that the
* block and all blocks above it are transparent for lighting purposes.
*
@@ -358,9 +329,7 @@ public interface World extends PluginMessageRecipient, Metadatable {
* @param delegate A class to call for each block changed as a result of
* this method
* @return true if the tree was created successfully, otherwise false
- * @deprecated rarely used API that was largely for implementation purposes
*/
- @Deprecated
public boolean generateTree(Location loc, TreeType type, BlockChangeDelegate delegate);
/**
@@ -757,31 +726,31 @@ public interface World extends PluginMessageRecipient, Metadatable {
* material.isBlock()}. The Material may not be air.
*
* @param location The {@link Location} to spawn the FallingBlock
- * @param material The block {@link Material} type
* @param data The block data
* @return The spawned {@link FallingBlock} instance
* @throws IllegalArgumentException if {@link Location} or {@link
- * Material} are null or {@link Material} is not a block
- * @deprecated Magic value
+ * BlockData} are null
*/
- @Deprecated
- public FallingBlock spawnFallingBlock(Location location, Material material, byte data) throws IllegalArgumentException;
+ public FallingBlock spawnFallingBlock(Location location, BlockData data) throws IllegalArgumentException;
/**
- * Spawn a {@link FallingBlock} entity at the given {@link Location} of
- * the specified blockId (converted to {@link Material})
+ * Spawn a {@link FallingBlock} entity at the given {@link Location} of the
+ * specified {@link Material}. The material dictates what is falling.
+ * When the FallingBlock hits the ground, it will place that block.
+ * <p>
+ * The Material must be a block type, check with {@link Material#isBlock()
+ * material.isBlock()}. The Material may not be air.
*
* @param location The {@link Location} to spawn the FallingBlock
- * @param blockId The id of the intended material
- * @param blockData The block data
- * @return The spawned FallingBlock instance
- * @throws IllegalArgumentException if location is null, or blockId is
- * invalid
- * @see #spawnFallingBlock(org.bukkit.Location, org.bukkit.Material, byte)
+ * @param material The block {@link Material} type
+ * @param data The block data
+ * @return The spawned {@link FallingBlock} instance
+ * @throws IllegalArgumentException if {@link Location} or {@link
+ * Material} are null or {@link Material} is not a block
* @deprecated Magic value
*/
@Deprecated
- public FallingBlock spawnFallingBlock(Location location, int blockId, byte blockData) throws IllegalArgumentException;
+ public FallingBlock spawnFallingBlock(Location location, Material material, byte data) throws IllegalArgumentException;
/**
* Plays an effect to all players within a default radius around a given
@@ -838,11 +807,11 @@ public interface World extends PluginMessageRecipient, Metadatable {
* @param z - chunk z coordinate
* @param includeBiome - if true, snapshot includes per-coordinate biome
* type
* @param includeBiomeTempRain - if true, snapshot includes per-coordinate
* raw biome temperature and rainfall
* @return The empty snapshot.
*/
- public ChunkSnapshot getEmptyChunkSnapshot(int x, int z, boolean includeBiome, boolean includeBiomeTempRain);
+ public ChunkSnapshot getEmptyChunkSnapshot(int x, int z, boolean includeBiome, boolean includeBiomeTemp);
/**
* Sets the spawn flags for this.
@@ -838,11 +807,11 @@ public interface World extends PluginMessageRecipient, Metadatable {
* @param includeBiome - if true, snapshot includes per-coordinate biome
* type
- * @param includeBiomeTempRain - if true, snapshot includes per-coordinate
- * raw biome temperature and rainfall
+ * @param includeBiomeTemp - if true, snapshot includes per-coordinate
+ * raw biome temperature
* @return The empty snapshot.
*/